@@ -1,9 +1,10 @@
 #!/bin/sh
 
-if [ -d "_MTN" ] && mtn automate get_workspace_root > /dev/null; then
+if [ -d "_MTN" ] && mtn automate get_workspace_root 2> /dev/null > /dev/null
+then
 VERSION_BASE=$(mtn automate get_base_revision_id)
 VERSION_CURRENT=$(mtn automate get_current_revision_id)
-VERSION_STATUS=$(mtn status)
+VERSION_STATUS=$(mtn diff | grep ^# | sed 's/"/\\"/g')
 else
 VERSION_BASE="unknown"
 VERSION_CURRENT="unknown"
@@ -12,7 +13,6 @@ fi
 
 
 BUILD_LABLGTK=$(${PKG_VERSION} lablgtk2)
-BUILD_LABLGTKSOURCEVIEW=$(${PKG_VERSION} lablgtksourceview)
 
 [ "${THREADS}" = "yes" ] && echo "let threads = T_thread.main"
 
@@ -25,7 +25,6 @@ let version_status = "${VERSION_STATUS}"
 
 let build_ocaml = "${OCAML_VERSION}"
 let build_lablgtk = "${BUILD_LABLGTK}"
-let build_lablgtksourceview = "${BUILD_LABLGTKSOURCEVIEW}"
 let conf_path = Sys.getenv "HOME" ^ "/.config/${PROJECT_NAME}/"
 let sys_data_path = "${SYSDATADIR}/${PROJECT_NAME}/"
 EOF
