@@ -5,4 +5,7 @@
  * terms of the GPL-3.0. For full license terms, see gpl-3.0.txt.
  *)
 
+val good_start : F.t
+val bad_start : F.t
+
 val action : (F.t -> unit) -> State.action -> unit
